@@ -36,15 +36,16 @@ def load_file(
     header of the file is loaded.
 
     Input:
-        qtynam: name of the quantities to extract from the file
-        impstm: stem of the file to import
-      **impdir: import directory (default: '')
-      **impfmt: import format (default: 'dat')
+        qtynam (list|tuple): name of the quantities to extract from the file
+        impstm (str): stem of the file to import
+      **impdir (str): import directory (default: '')
+      **impfmt (str): import format (default: 'dat')
 
     Output:
         qtyval: quantity values in the order of qtynam
 
     The following variables can be loaded:
+        'stm' (str): output stem
         'v' (str): lpa-xrd version
         'd' (Scalar): dislocation density [m^-2]
         'z' (Vector): direction of 'l' (line vector) [uvw]
@@ -77,7 +78,8 @@ def load_file(
         i = 0 # index on qtynam
         while i<len(qtynam) and not imptab: # stops when element is in table
             if qtynam[i]=='A' or qtynam[i] in tq: # the quantity is in table
-                td = [l.split() for l in f.readlines()] # load table data
+                td = np.loadtxt(f).T # table data
+                nj = (len(tq)-3)//4 # number of harmonics
                 imptab = True # inform that the table has been imported
             i += 1 # go to next requested quantity
     qtyval = [] # values of the quantities in qtynam
@@ -91,15 +93,12 @@ def load_file(
             return v
         elif nam in tq: # the quantity is in the table
             j = tq.index(nam)
-            return np.array([eval(td[i][j]) for i in range(len(td))])
+            return td[j]
         elif nam == 'A':
-            a = (
-                np.array([
-                    np.array([eval(td[i][4*h+1]) for i in range(len(td))])
-                +1j*np.array([eval(td[i][4*h+3]) for i in range(len(td))])
-                for h in range((len(tq)-3)//4)])
-            )
+            a = np.array([td[4*h+1] + 1j*td[4*h+3] for h in range(nj)])
             return a
+        elif nam == 'stm':
+            return impstm
         else:
             raise ValueError(f"unknown quantity: {nam}")
     for nam in qtynam:
@@ -120,9 +119,9 @@ def load_directory(
     as in function load_file can be extracted.
 
     Input:
-        qtynam: name of the quantities to extract and average
-        impstm: stem of the directory to import
-      **impdir: import directory (default: see load_file)
+        qtynam (list|tuple): name of the quantities to extract and average
+        impstm (str): stem of the directory to import
+      **impdir (str): import directory (default: see load_file)
 
     Ouput:
         qtyval: averaged quantity values in the order of qtynam
@@ -139,13 +138,56 @@ def load_directory(
         dv.append(val) # store data
     qtyval = [] # averaged values
     for j in range(len(qtynam)):
-        if qtynam[j]!='v':
+        if qtynam[j]=='v':
+            qtyval.append(dv[0][j])
+        elif qtynam[j]=='stm':
+            qtyval.append(impstm)
+        else:
             lstval = [dv[i][j] for i in range(len(stm_fmt))] # to average
             qtyval.append(sum(lstval)/len(lstval)) # store mean
-        else:
-            qtyval.append(dv[0][j]) # store mean
     return tuple(qtyval)
 
+@beartype
+def average(
+    impnam: str,
+    **kwargs: str,
+) -> None:
+    """
+    Produce a file resulting from the averaging of a sample.
+
+    Input:
+        impnam (str): name of the output directory
+      **impdir (str): import directory (default: '')
+      **expdir (str): export directory (default: impdir)
+      **fmtout (str): data export format (default: 'dat')
+    """
+    impdir = getkwa('impdir', kwargs, str, '')
+    expdir = getkwa('expdir', kwargs, str, impdir)
+    fmtout = getkwa('fmtout', kwargs, str, 'dat')
+    endkwa(kwargs)
+    smpdir = os.path.join(impdir, impnam)
+    avgfil = os.path.join(expdir, impnam)
+    # retrive data
+    with open(os.path.join(smpdir, os.listdir(smpdir)[0]), 'r') as f:
+        hdr = [f.readline() for i in range(12)]
+    clm = hdr[-1].split()[1:]
+    qtynam = ['d']+clm
+    res = load_directory(qtynam, impnam, impdir=impdir)
+    dst = res[0]
+    tab = list(res[1:])
+    j = (len(clm)-3)//4
+    n = len(os.listdir(smpdir))
+    # edit data
+    hdr[1] = f"{dst:8.2e} #" + hdr[1].split('#')[1]
+    for h in range(j):
+        for i in [1, 3]:
+            tab[1+4*h+i] /= np.sqrt(n)
+    # write data
+    fmt = "%6.1f" + " %22.15E %14.7E %22.15E %14.7E"*j + " %22.15E %10d"
+    with open(f"{avgfil}.{fmtout}", 'w') as f:
+        f.write("".join(hdr))
+        np.savetxt(f, np.array(tab).T, fmt=fmt)
+
 @beartype
 def load(
     qtynam: Union[list, tuple],
@@ -156,9 +198,9 @@ def load(
     Return the values of qtynam from a simulation output file or dir.
 
     Input:
-        qtynam: name of the quantities to extract
-        impnam: name of the directory or output file to load
-      **impdir: import directory (default: see load_file)
+        qtynam (list|tuple): name of the quantities to extract
+        impnam (str): name of the directory or output file to load
+      **impdir (str): import directory (default: see load_file)
 
     Output:
         qtyval: quantity values in the order of qtynam
@@ -172,6 +214,8 @@ def load(
         stm, fmt = os.path.splitext(impnam)
         return load_file(qtynam, stm, impdir=impdir, impfmt=fmt[1:])
     elif os.path.isdir(outpth): # load and average the output directory
-        return load_directory(qtynam, impnam, impdir=impdir)
+        if not os.path.isfile(f"{outpth}.dat"):
+            average(impnam, impdir=impdir, expdir=impdir)
+        return load_file(qtynam, impnam, impfmt='dat', impdir=impdir)
     else:
         raise ValueError(f"nothing found at specified path: {outpth}")
